""" A module providing information on build-time configuration of pacemaker """

__all__ = ["BuildOptions"]
__copyright__ = "Copyright 2023 the Pacemaker project contributors"
__license__ = "GNU Lesser General Public License version 2.1 or later (LGPLv2.1+)"

class BuildOptions:
    """ Variables generated as part of the ./configure && make process.  These
        affect how pacemaker was configured and where its various parts get
        installed.
    """

    BASH_PATH = "/usr/local/bin/bash"
    """ Path to the bash shell """

    _BUILD_DIR = "/wrkdirs/usr/ports/net/pacemaker2/work/pacemaker-Pacemaker-2.1.7"
    """ Top-level build directory
        NOTE: This is not especially useful on installed systems, but is useful for
        running various programs from a source checkout
    """

    CIB_DIR = "/var/lib/pacemaker/cib"
    """ Where CIB files are stored """

    CIB_SCHEMA_VERSION = "3.9"
    """ Latest supported CIB schema version number """

    COROSYNC_CONFIG_FILE = "/usr/local/etc/corosync/corosync.conf"
    """ Path to the corosync config file """

    DAEMON_DIR = "/usr/local/libexec/pacemaker"
    """ Where Pacemaker daemons are installed """

    DAEMON_USER = "hacluster"
    """ User to run Pacemaker daemons as """

    LOCAL_STATE_DIR = "/var"
    """ Where miscellaneous temporary state files are stored """

    LOG_DIR = "/var/log/pacemaker"
    """ Where Pacemaker log files are stored """

    OCF_RA_INSTALL_DIR = "/usr/local/lib/ocf/resource.d"
    """ Where resource agents are installed """

    OCF_ROOT_DIR = "/usr/local/lib/ocf"
    """ Root directory for OCF resource agents and libraries """

    RSC_TMP_DIR = "/var/run/resource-agents"
    """ Where resource agents should keep state files """

    # pylint: disable=comparison-of-constants
    REMOTE_ENABLED = "gnutls" != ""
    """ Was Pacemaker Remote support built? """

    SBIN_DIR = "/usr/local/sbin"
    """ Where administrative programs are installed """

    SCHEMA_DIR = "/usr/local/share/pacemaker"
    """ Where Relax-NG schema files are stored """
